@@ -398,15 +398,37 @@ func TestShadows(t *testing.T) {
 }
 
 // TestMountPasswordIncorrect makes sure the correct exit code is used when the password
-// was incorrect while mounting
+// was incorrect while mounting.
+// Also checks that we don't leave a socket file behind.
 func TestMountPasswordIncorrect(t *testing.T) {
 	cDir := test_helpers.InitFS(t) // Create filesystem with password "test"
+	ctlSock := cDir + ".sock"
 	pDir := cDir + ".mnt"
-	err := test_helpers.Mount(cDir, pDir, false, "-extpass", "echo WRONG", "-wpanic=false")
+	err := test_helpers.Mount(cDir, pDir, false, "-extpass", "echo WRONG", "-wpanic=false", "-ctlsock", ctlSock)
 	exitCode := test_helpers.ExtractCmdExitCode(err)
 	if exitCode != exitcodes.PasswordIncorrect {
 		t.Errorf("want=%d, got=%d", exitcodes.PasswordIncorrect, exitCode)
 	}
+	if _, err := os.Stat(ctlSock); err == nil {
+		t.Errorf("socket file %q left behind", ctlSock)
+	}
+}
+
+// TestMountPasswordEmpty makes sure the correct exit code is used when the password
+// was empty while mounting.
+// Also checks that we don't leave a socket file behind (https://github.com/rfjakob/gocryptfs/issues/634).
+func TestMountPasswordEmpty(t *testing.T) {
+	cDir := test_helpers.InitFS(t) // Create filesystem with password "test"
+	ctlSock := cDir + ".sock"
+	pDir := cDir + ".mnt"
+	err := test_helpers.Mount(cDir, pDir, false, "-extpass", "true", "-wpanic=false", "-ctlsock", ctlSock)
+	exitCode := test_helpers.ExtractCmdExitCode(err)
+	if exitCode != exitcodes.ReadPassword {
+		t.Errorf("want=%d, got=%d", exitcodes.ReadPassword, exitCode)
+	}
+	if _, err := os.Stat(ctlSock); err == nil {
+		t.Errorf("socket file %q left behind", ctlSock)
+	}
 }
 
 // TestPasswdPasswordIncorrect makes sure the correct exit code is used when the password
@@ -929,7 +951,7 @@ func TestInitNotEmpty(t *testing.T) {
 }
 
 // TestSharedstorage checks that `-sharedstorage` shows stable inode numbers to
-// userpsace despite having hard link tracking disabled
+// userspace despite having hard link tracking disabled
 func TestSharedstorage(t *testing.T) {
 	dir := test_helpers.InitFS(t)
 	mnt := dir + ".mnt"
@@ -982,7 +1004,7 @@ func TestMountCreat(t *testing.T) {
 		for i := 0; i < concurrency; i++ {
 			go func(i int) {
 				path := fmt.Sprintf("%s/%d", mnt, i)
-				fd, err := syscall.Creat(path, 0600)
+				fd, err := syscall.Open(path, syscall.O_CREAT|syscall.O_WRONLY|syscall.O_TRUNC, 0600)
 				syscall.Close(fd)
 				if err != nil {
 					t.Errorf("Creat %q: %v", path, err)
